==> pylog-0.1.7.tar.gz: pylog-0.1.7/pylog/cli.py <==
# flake8: NOQA
"""Script to run pylog via command line

Usage:
    pylog gen [--config=<path> --transport=<string> --format=<string> --gap=<int> --messages=<int> --batch=<int> -v]
    pylog list fake
    pylog --version

Arguments:
    gen         Generates Logs
    list fake   Lists different data options (with an example)

Options:
    -h --help                   Show this screen.
    -c --config=<path>          Path to generator config file
    -t --transport=<string>     transport to use (e.g. FileTransport)
    -f --format=<string>        output format (e.g. JsonFormatter)
    -g --gap=<int>              Number of seconds between messages (can be less than 1)
    -m --messages=<int>         Number of messages to generate
    -b --batch=<int>            Number of messages to stack before shipping
    -v --verbose                a LOT of output
    --version                   Display current version of pylog and exit

"""

from __future__ import absolute_import
from docopt import docopt
from pylog.pylog import init_logger
from pylog.pylog import _set_global_verbosity_level
from pylog.pylog import generator, list_fake_types

lgr = init_logger()


def ver_check():
    import pkg_resources
    version = None
    try:
        version = pkg_resources.get_distribution('pylog').version
    except Exception as e:
        print(e)
    finally:
        del pkg_resources
    return version


def pylog_run(o):
    if o['list'] and o['fake']:
        list_fake_types()
    elif o['gen']:
        generator(config=o.get('--config'),
                 transport=o.get('--transport'),
                 formatter=o.get('--format'),
                 gap=o.get('--gap'),
                 messages=o.get('--messages'),
                 batch=o.get('--batch'),
                 verbose=o.get('--verbose'))


def pylog(test_options=None):
    """Main entry point for script."""
    version = ver_check()
    options = test_options or docopt(__doc__, version=version)
    _set_global_verbosity_level(options.get('--verbose'))
    lgr.debug(options)
    pylog_run(options)


def main():
    pylog()


if __name__ == '__main__':
    main()

==> pylog-0.2.0.tar.gz: pylog-0.2.0/pylog/cli.py <==
# flake8: NOQA
"""Script to run pylog via command line

Usage:
    pylog gen [--config=<path> --transport=<string> --format=<string> --gap=<int> --messages=<int> --batch=<int> -v]
    pylog list (fake|transports|formatters)
    pylog --version

Arguments:
    gen                 Generates Logs
    list fake           Lists different data options (with an example)
    list transports     Lists the type of transports available
    list formatters     Lists the type of formatters available

Options:
    -h --help                   Show this screen.
    -c --config=<path>          Path to generator config file.
    -t --transport=<string>     transport to use (e.g. File)
    -f --format=<string>        output format (e.g. Json)
    -g --gap=<int>              Number of seconds between messages (can be less than 1)
    -m --messages=<int>         Number of messages to generate
    -b --batch=<int>            Number of messages to stack before shipping
    -v --verbose                a LOT of output
    --version                   Display current version of pylog and exit

"""

from __future__ import absolute_import
from docopt import docopt
from pylog.pylog import init_logger
from pylog.pylog import _set_global_verbosity_level
from pylog.pylog import generator
from pylog.pylog import list_fake_types, list_transports, list_formatters

lgr = init_logger()


def ver_check():
    import pkg_resources
    version = None
    try:
        version = pkg_resources.get_distribution('pylog').version
    except Exception as e:
        print(e)
    finally:
        del pkg_resources
    return version


def pylog_run(o):
    if o['list']:
        if o['fake']:
            list_fake_types()
        elif o['transports']:
            list_transports()
        elif o['formatters']:
            list_formatters()

    elif o['gen']:
        generator(config=o.get('--config'),
                 transport=o.get('--transport'),
                 formatter=o.get('--format'),
                 gap=o.get('--gap'),
                 messages=o.get('--messages'),
                 batch=o.get('--batch'),
                 verbose=o.get('--verbose'))


def pylog(test_options=None):
    """Main entry point for script."""
    version = ver_check()
    options = test_options or docopt(__doc__, version=version)
    _set_global_verbosity_level(options.get('--verbose'))
    lgr.debug(options)
    pylog_run(options)


def main():
    pylog()


if __name__ == '__main__':
    main()
